function [alldata, labels, sizeMat] = getAllData(queryGOID)

global arrayData;
global arrayInd;
global arrayGenes;
global Annot;
maxExp = 44;   %total number of experiments in the dataset
global GO
arrayInd = arrayInd';
arrayGenes = lower(arrayGenes);

GOgenes = {Annot.DB_Object_Symbol};  %the full arabidopsis gene list from the annotation file
GOID = [Annot.GOid];    %get associated GO terms
Aspect = {Annot.Aspect};  %get the 3 ontologies
Evidence = {Annot.Evidence};
BPMask = strcmp({Annot.Aspect}, 'P');  %Get only biological process terms
GOgenes = GOgenes(BPMask);  %get genes from biological process tree
GOID = GOID(BPMask);   %get GO terms from biological process treee
Evidence = Evidence(BPMask);    %get evidence codes from genes in biological process tree
EvMask = ismember(Evidence, {'EXP' 'IDA' 'IPI' 'IMP' 'IGI' 'IEP' 'ISS' 'IC' 'ISO' 'ISA' 'ISM' 'IGC'}'); % all annotations except microarrays and electronic
GOgenes = GOgenes(:,EvMask);  %retrieve experimentally annotated genes
GOgenes = lower(GOgenes);
GOID = GOID(:, EvMask);   %retrieve experimentally annotated GO terms

geneproc = [];
dataproc = [];
labelproc = [];
sizeproc = [];
GOstruct = GO(queryGOID);
for i = 1:length(queryGOID)
    
    queryLabel = cellstr(GOstruct.term(i).name);   %retrieves GO annotation for each of the query GOIDs
    desID = getdescendants(GO, queryGOID(i));   %gets all the descendant GO:IDs
    Gidx = ismember(GOID, desID);
    retGenes = unique(GOgenes(:, Gidx));   %retrieve genes which belong to the descendants
    retGenes = cellstr(lower(retGenes'));
    
    if i ==1
        N = 35;  % get only N number of genes from each category
    else N = 1;
    end
    if isempty(retGenes)
        retGenes = ('');
    elseif (length(retGenes)<N)
        retGenes = retGenes(1:length(retGenes));
    else retGenes = retGenes(1:N);  %restrict the number of genes retrieved to N for each GO category
    end
    %%%% extracting gene expression data
    Lidx = ismember(lower(arrayGenes), lower(retGenes));
    allData = arrayData(Lidx,:);  %retrieves data from all experiments
    getGenes = arrayGenes(Lidx,:);
    getSize = length(getGenes);
    getLabels = repmat(queryLabel, length(getGenes),1);
    %%% complete dataset retrieved
    geneproc = [geneproc; getGenes];
    labelproc = [labelproc; getLabels];
    dataproc = [dataproc; allData];
    sizeproc = [sizeproc; getSize];
    
end
sizeMat = sizeproc(1);
%%%%seperate background data
restGenes = geneproc(sizeproc(1)+1:end, :);
restLabels = labelproc(sizeproc(1)+1:end, :);
restData = dataproc(sizeproc(1)+1:end,:);
%%%%%%make unique genes dataset for the background data
[uniqGenes, m, n] = unique(restGenes);
uniqLabels = restLabels(m);
uniqData = restData(m,:);
%%%%%%%% prepare data for output: concatenate unique background gene data
%%%%%%%% with the query gene data
labels = [labelproc(1:sizeMat(1)); uniqLabels];
alldata = [dataproc(1:sizeMat(1),:); uniqData];


