%function takes the foreground id as the input, gets all background GOID
%such that the list contains no descendants of the input id and the GOIDs
%have atleast one of the annotated genes in the microarray data


function [bgLabels] = getallBGid(fgLabel)

global Annot 
global genes
global GO 

GOgenes = {Annot.DB_Object_Symbol};  %the full arabidopsis gene list from the annotation file
GOID = [Annot.GOid];    %get associated GO terms
Aspect = {Annot.Aspect};  %get the 3 ontologies
Evidence = {Annot.Evidence};
BPMask = strcmp({Annot.Aspect}, 'P');  %Get only biological process terms
GOgenes = GOgenes(BPMask);  %get genes from biological process tree
GOID = GOID(BPMask);   %get GO terms from biological process treee
Evidence = Evidence(BPMask);    %get evidence codes from genes in biological process tree
EvMask = ismember(Evidence, {'EXP' 'IDA' 'IPI' 'IMP' 'IGI' 'IEP' 'ISS' 'IC' 'ISO' 'ISA' 'ISM' 'IGC'}'); % all annotations except microarrays and electronic 
GOgenes = GOgenes(:,EvMask);  %retrieve experimentally annotated genes
GOgenes = lower(GOgenes);
GOID = GOID(:, EvMask);   %retrieve experimentally annotated GO terms
GOIDlist = GOID;
GOgenesList = GOgenes;
inputLabels = getdescendants(GO, fgLabel);
goidx = ismember(GOIDlist, inputLabels);
GOIDlist(goidx) = [];  %filter out Foreground GO label and its descendents from the GOID list
GOgenesList(goidx) = [];
geneidx = ismember(lower(GOgenesList), lower(genes)); %Remove genes in the GO list which are not found in the microarray
GOIDlist(geneidx) = [];   
%%%%%%% remove any obsolete IDs present in the list
obs = get(GO.terms,'obsolete');
mask = ismember(cell2mat(obs), 1);
obsTermsStruct = GO.terms(mask);
obsTerms = cell2mat(get(obsTermsStruct,'id'));  % make a list of obsolete IDs

terms = get(GO.terms,'id');
idx1 = ismember(GOIDlist, cell2mat(terms'));
GOIDlist(~idx1) = [];  %filter out any IDs not present in the GOtree
idx = ismember(GOIDlist, obsTerms');
GOIDlist(idx) = [];   % filter out obsolete terms from GOID list
bgLabels = unique(GOIDlist);








